context("canvasXpress Web Charts - Genome")


test_that("cXgenome1", {
    check_ui_test(cXgenome1())
})

test_that("cXgenome2", {
    check_ui_test(cXgenome2())
})

test_that("cXgenome3", {
    check_ui_test(cXgenome3())
})
